@@ -116,5 +116,5 @@ class MaxFormatter:
             raise TypeError("Cannot parse dicts as return arguments")  # TODO: Handle when implem. dict strategy
         else:
             for e in l:
-                MaxFormatter._flatten(flat_list, e)
+                MaxFormatter._flatten(flat_list, e, cnmat_compatibility=cnmat_compatibility)
         return flat_list
